# Changelog

## [0.2.3](https://github.com/ongyjho/hawaiidisco/compare/v0.2.2...v0.2.3) (2026-02-17)


### Bug Fixes

* guard DetailView queries against NoMatches during mount race ([8a19321](https://github.com/ongyjho/hawaiidisco/commit/8a19321d575d3f4a1d9c731f766b9a47beb1585f))


### Documentation

* update README and version for v0.2.2 ([bcc53c7](https://github.com/ongyjho/hawaiidisco/commit/bcc53c7ba3c59a6d895d532b2062db9acdf3688d))
* update README and version for v0.2.2 ([49b4898](https://github.com/ongyjho/hawaiidisco/commit/49b4898a0e1a0975dc14c44dd9caf73e3293782b))

## [0.2.2](https://github.com/ongyjho/hawaiidisco/compare/v0.2.1...v0.2.2) (2026-02-17)


### Bug Fixes

* remove duplicate force-include causing PyPI upload failure ([d70eee3](https://github.com/ongyjho/hawaiidisco/commit/d70eee310daf67601d752741668df4cbb246c5e2))
* remove duplicate force-include causing PyPI upload failure ([fdfd40f](https://github.com/ongyjho/hawaiidisco/commit/fdfd40f620ceb44d578f0eb94a4e888b155427d7))


### Miscellaneous

* **main:** release 0.2.1 ([4af5d53](https://github.com/ongyjho/hawaiidisco/commit/4af5d53310b3661553f27b1ca4942a9fda3c6a62))
* **main:** release 0.2.1 ([c918e89](https://github.com/ongyjho/hawaiidisco/commit/c918e896d374c01b097fa422f25762603040ab35))

## [0.2.1](https://github.com/ongyjho/hawaiidisco/compare/v0.2.0...v0.2.1) (2026-02-17)


### Bug Fixes

* remove duplicate force-include causing PyPI upload failure ([d70eee3](https://github.com/ongyjho/hawaiidisco/commit/d70eee310daf67601d752741668df4cbb246c5e2))
* remove duplicate force-include causing PyPI upload failure ([fdfd40f](https://github.com/ongyjho/hawaiidisco/commit/fdfd40f620ceb44d578f0eb94a4e888b155427d7))

## [0.2.0](https://github.com/ongyjho/hawaiidisco/compare/v0.1.0...v0.2.0) (2026-02-17)


### Features

* add emoji reactions to [@review](https://github.com/review) comments ([761aeec](https://github.com/ongyjho/hawaiidisco/commit/761aeecb6c733d8860da5fce47477f03ece4b5d6))
* add Obsidian vault integration for bookmarked articles ([2fd32fb](https://github.com/ongyjho/hawaiidisco/commit/2fd32fb2fdc22de5e936a583a7bc3409a63af8c8))
* add Obsidian vault integration for bookmarked articles ([ce422ed](https://github.com/ongyjho/hawaiidisco/commit/ce422ed11a51215233f69f1a81d4303a477312e0))
* add verdict badge (approve/request_changes) to review comments ([036ba31](https://github.com/ongyjho/hawaiidisco/commit/036ba3163f5b96ba7c5d256e3af5e0b972de4063))
* auto-create GitHub issues from AI review suggestions ([895d882](https://github.com/ongyjho/hawaiidisco/commit/895d88249418a69708b417e8a4b192e1ab4c7faa))
* auto-create GitHub issues from AI review suggestions ([6ea011d](https://github.com/ongyjho/hawaiidisco/commit/6ea011dc76e70fbf01e3fcf48d889f43650c4cf9))
* expand i18n to 6 languages (EN/KO/JA/ZH-CN/ES/DE) ([a587686](https://github.com/ongyjho/hawaiidisco/commit/a58768637209db042387d003fc2cba5484267dd0))
* expand i18n to 6 languages with YAML-based locale system ([580d7ad](https://github.com/ongyjho/hawaiidisco/commit/580d7adefac724defccb3adfd04bd273abb94d26))


### Bug Fixes

* skip PR review gracefully when OPENAI_API_KEY is not set ([43b013d](https://github.com/ongyjho/hawaiidisco/commit/43b013d1271ccfb2222457ee2a06c6f70d4e0ff8))


### Miscellaneous

* switch all review output and prompts to English ([3f95cdd](https://github.com/ongyjho/hawaiidisco/commit/3f95cdd729893914939246472746b5320a614dc0))
